<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Închide programul </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Display help </source>
        <translation>Afișează ajutor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>About this application</source>
        <translation>Informații despre program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>About...</source>
        <translation>Despre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>View Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <location filename="../mainwindow.cpp" line="527"/>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select ISO</source>
        <translation>Selectare ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selectare Dispozitiv Țintă USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selectare fișier ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Advanced Options</source>
        <translation>Opțiuni Avansate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Creează sistemul de fișiere ext4 chiar dacă există unul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Salvează directorul inițial de încărcare când actualizați un live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Utilizare partiționare gpt în loc de msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>GPT partitioning</source>
        <translation>Partiționare GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualizare (actualizează numai un live-usb existent)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Nu înlocuiește fișierele syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Keep syslinux files</source>
        <translation>Păstrare fișierele syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorare verificarea USB/detașabil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Temporarily disable automounting</source>
        <translation>Dezactivare temporară a montării automate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Setare pmbr_boot pe disc (nu va porni prin UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Mărimea partiției ESP (uefi) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbositate (de la puțin la mai mult):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>vfat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>exfat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>ntfs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>Make separate data partition (percent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Format</source>
        <translation>Formatare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Refresh drive list</source>
        <translation>Actualizare listă dispozitive</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Show advanced options</source>
        <translation>Arată opțiuni avansate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="583"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Numai pentru citire, nu poate fi folosit cu persistență</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Pentru alte distribuții decât antiX/MX, utilizați numai opțiunea mod imagine (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Options</source>
        <translation>Opțiuni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Percent of USB-device to use:</source>
        <translation>Procentul utilizat din dispozitivului USB:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <source>Label ext partition:</source>
        <translation>Etichetă partiție ext</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Nu executază comenzi care afectează dispozitivul USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Dry run (no change to system)</source>
        <translation>Încercare (fără schimbari în sistem)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>clonare dintr-un fișier live-usb sau iso-mount.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Clone a mounted live system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone an existing live system</source>
        <translation type="vanished">Clonare a unui sistem live</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Configurare pentru a porni de pe o partiție criptată, va solicita o parola la prima încărcare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Encrypt</source>
        <translation>Criptare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Clone running live system</source>
        <translation>Clonarea sistemului live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Confirmation</source>
        <translation>Confirmație</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Failure</source>
        <translation>Eșec</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Sursa și destinația sunt pe același dispozitiv, selectați din nou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>MX Live Usb Maker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>LiveUSB creation successful!</source>
        <translation>Crearea LiveUSB a reușit!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Eroare întâlnită în procesul de creare a LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Please select a USB device to write to</source>
        <translation>Selectați un dispozitiv USB pe care să scrieți</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="397"/>
        <source>These actions will destroy all data on 

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Do you wish to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>Version: </source>
        <translation>Versiune:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pentru crearea unui live-usb dintr-un fișier iso, un alt live-usb, un live-cd/dvd sau un sistem care rulează live.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Selectați un fișier ISO pentru a scrie pe unitatea USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>Select Source Directory</source>
        <translation>Selectare Director Sursă</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Nu s-a putut găsi fișierul %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Hide advanced options</source>
        <translation>Ascunde opțiunile avansate</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Select Source</source>
        <translation>Selectare sursă</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Select ISO file</source>
        <translation>Selectare fișier ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>clone</source>
        <translation>clonă</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licență</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Închide</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pentru crearea unui live-usb dintr-un fișier iso, un alt live-usb, un live-cd/dvd sau un sistem care rulează live.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>[filename]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>Trebuie să rulați acest program ca administrator.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
